# pingnet
## Multi-threaded Python script to run multiple ping tests, including hostnames and CIDR IPv4 blocks.

Returns RTT value on reachable addresses.

Create hosts.txt with address on each line

hosts.txt Example:

8.8.8.8
1.1.1.1
google.com
8.8.8.8/24
kevinjin.com



Outputs results in txt format. 
